@@ -11,6 +11,7 @@ import (
 type CandidateNode struct {
 	Node   *yaml.Node     // the actual node
 	Parent *CandidateNode // parent node
+	Key    *yaml.Node     // node key, if this is a value from a map (or index in an array)
 
 	LeadingContent string
 
@@ -38,11 +39,41 @@ func (n *CandidateNode) AsList() *list.List {
 	return elMap
 }
 
-func (n *CandidateNode) CreateChild(path interface{}, node *yaml.Node) *CandidateNode {
+func (n *CandidateNode) CreateChildInMap(key *yaml.Node, node *yaml.Node) *CandidateNode {
+	var value interface{} = nil
+	if key != nil {
+		value = key.Value
+	}
 	return &CandidateNode{
 		Node:      node,
-		Path:      n.createChildPath(path),
+		Path:      n.createChildPath(value),
 		Parent:    n,
+		Key:       key,
+		Document:  n.Document,
+		Filename:  n.Filename,
+		FileIndex: n.FileIndex,
+	}
+}
+
+func (n *CandidateNode) CreateChildInArray(index int, node *yaml.Node) *CandidateNode {
+	return &CandidateNode{
+		Node:      node,
+		Path:      n.createChildPath(index),
+		Parent:    n,
+		Key:       &yaml.Node{Kind: yaml.ScalarNode, Value: fmt.Sprintf("%v", index), Tag: "!!int"},
+		Document:  n.Document,
+		Filename:  n.Filename,
+		FileIndex: n.FileIndex,
+	}
+}
+
+func (n *CandidateNode) CreateReplacement(node *yaml.Node) *CandidateNode {
+	return &CandidateNode{
+		Node:      node,
+		Path:      n.createChildPath(nil),
+		Parent:    n.Parent,
+		Key:       n.Key,
+		IsMapKey:  n.IsMapKey,
 		Document:  n.Document,
 		Filename:  n.Filename,
 		FileIndex: n.FileIndex,
